/*
Pluck: an open source trivia game for Android

Copyright (C) 2021 Joguitos do luca0N!

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <https://www.gnu.org/licenses/>.

This game is a fork of LibreTrivia, and its source code is available at
<https://github.com/tryton-vanmeer/LibreTrivia>.

Contact us at <joguitos+pluck@luca0n.com>.
*/

package com.luca0n.joguitos.pluck.activities;

import android.content.Intent;
import android.os.Build;
import android.os.Bundle;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.Spinner;
import androidx.appcompat.app.AlertDialog;

import butterknife.BindView;
import butterknife.ButterKnife;
import com.luca0n.joguitos.pluck.R;
import com.luca0n.joguitos.pluck.trivia.TriviaSource;
import com.luca0n.joguitos.pluck.trivia.TriviaCategory;
import com.luca0n.joguitos.pluck.trivia.TriviaDifficulty;
import com.luca0n.joguitos.pluck.trivia.TriviaQuery;

public class MainActivity extends BaseActivity {

	@BindView(R.id.button_play)
	Button buttonPlay;
	@BindView(R.id.spinner_source)
	Spinner spinnerSource;
	@BindView(R.id.spinner_number)
	Spinner spinnerNumber;
	@BindView(R.id.spinner_category)
	Spinner spinnerCategory;
	@BindView(R.id.spinner_difficulty)
	Spinner spinnerDifficulty;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		ButterKnife.bind(this);

		buttonPlay.setOnClickListener(v -> {
			int sourcePos = spinnerSource.getSelectedItemPosition();
			if (TriviaSource.values()[sourcePos] ==  TriviaSource.FILE){
				// Check the Android version.
				if (Build.VERSION.SDK_INT >= 19){
					// TODO: Show the open document dialog and read the trivia file.
					return;
				} else {
					// Unsupported version.
					new AlertDialog.Builder(this)
					.setIcon(android.R.drawable.ic_dialog_alert)
					.setTitle(R.string.error)
					.setMessage(R.string.error_source_file_android_version_unsupported)
					.setPositiveButton(android.R.string.ok, null)
					.show();	
				}
				return;
			}
			int amount = (int) spinnerNumber.getSelectedItem();
			TriviaCategory category = (TriviaCategory) spinnerCategory.getSelectedItem();
			TriviaDifficulty difficulty = (TriviaDifficulty) spinnerDifficulty.getSelectedItem();

			TriviaQuery query = new TriviaQuery.Builder(amount)
				.category(category)
				.difficulty(difficulty)
				.build();

			Intent intent = new Intent(getApplicationContext(), TriviaGameActivity.class);
			intent.putExtra(TriviaGameActivity.EXTRA_TRIVIA_QUERY, query);
			startActivity(intent);
		});

		Integer[] numbers = new Integer[50];
		for (int i = 0; i < 50; ) {
			numbers[i] = ++i;
		}
		spinnerSource.setAdapter(
				new ArrayAdapter<>(
					this, android.R.layout.simple_list_item_1, TriviaSource.values())
				);
		spinnerNumber.setAdapter(
				new ArrayAdapter<>(
					this, android.R.layout.simple_list_item_1, numbers)
				);
		spinnerNumber.setSelection(9);

		spinnerCategory.setAdapter(
				new ArrayAdapter<>(
					this, android.R.layout.simple_list_item_1, TriviaCategory.values()));

		spinnerDifficulty.setAdapter(
				new ArrayAdapter<>(
					this, android.R.layout.simple_list_item_1, TriviaDifficulty.values()));
	}
}
